@@ -82,6 +82,9 @@ def fup_or_defup():
         consumption_ko = core.get_consommation_sum(customer_name)
         consumption = consumption_ko / 1000000000
         fup_status = consumption > data_limit
+        LOGS.logger.info(
+            "consumption: {}/{}Go - fuped: {}".format(consumption, data_limit, fup_status)
+        )
         core.update_consommation(product, policy, customer_name, fup_status, consumption)
 
         # if fup_status:
