@@ -480,7 +480,7 @@ def get_consommation_sum(customer):
     """
     Fetches the last 30days consumptions of a customer
     """
-    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
+    thirty_days_ago = (dt.today() - timedelta(days=31)).strftime("%Y-%m-%d")
     sql = (
         "SELECT SUM(octets_in+octets_out) "
         "FROM cdr "
@@ -491,7 +491,7 @@ def get_consommation_sum(customer):
         "AND extract(HOUR FROM datetime) < 19 "
         "AND extract(HOUR FROM datetime) > 8 "
         "GROUP BY customer;"
-    ).format(customer=customer, date=yesterday)
+    ).format(customer=customer, date=thirty_days_ago)
     try:
         with records.Database(si_database_url()) as db:
             rows = db.query(sql)
@@ -501,8 +501,8 @@ def get_consommation_sum(customer):
             else:
                 total = 0
             LOGS.logger.info(
-                "Customer {} 30days total consumption: {}"
-                .format(customer, total)
+                "Customer {} 30days total consumption: {} ({}Go)"
+                .format(customer, total, total/1000000000)
             )
             return total
     except Exception as e:
